@@ -25,7 +25,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( CheckDigits );
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 my %methods = (
 	'mbase-001'		=> 'Algorithm::CheckDigits::MBase_001',
@@ -132,6 +132,10 @@ my %methods = (
 	'iban'			=> 'Algorithm::CheckDigits::M97_002',
 	'mxx-001'		=> 'Algorithm::CheckDigits::MXX_001',
 	'pa_de'			=> 'Algorithm::CheckDigits::MXX_001',
+	'mxx-002'		=> 'Algorithm::CheckDigits::MXX_002',
+	'cas'			=> 'Algorithm::CheckDigits::MXX_002',
+	'mxx-003'		=> 'Algorithm::CheckDigits::MXX_003',
+	'dem'			=> 'Algorithm::CheckDigits::MXX_003',
 );
 
 sub CheckDigits {
